==> jc-1.4.0.tar.gz: jas/TableswitchOperand.h <==
// class jas.TableswitchOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class f525ab7ff12da576 jas_TableswitchOperand
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_TableswitchOperand_H_
#define _JC_jas_TableswitchOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Insn$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_TableswitchOperand$sub_refs	_jc_jas_TableswitchOperand$sub_refs;
typedef struct _jc_jas_TableswitchOperand$sub_nonrefs	_jc_jas_TableswitchOperand$sub_nonrefs;
typedef struct _jc_jas_TableswitchOperand$refs	_jc_jas_TableswitchOperand$refs;
typedef struct _jc_jas_TableswitchOperand$nonrefs	_jc_jas_TableswitchOperand$nonrefs;
typedef struct _jc_jas_TableswitchOperand$object	_jc_jas_TableswitchOperand$object;

typedef const struct _jc_jas_TableswitchOperand$vmethods	_jc_jas_TableswitchOperand$vmethods;
typedef const struct _jc_jas_TableswitchOperand$vtable	_jc_jas_TableswitchOperand$vtable;
typedef const struct _jc_jas_TableswitchOperand$vtype	_jc_jas_TableswitchOperand$vtype;

// Constructors
extern void _jc_jas_TableswitchOperand$method$_init$cd7d55db5f4aa5ab(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_Insn$object *, jint, jint, struct _jc_jas_Label$object *, struct _jc_object_array *);

// Virtual methods
extern void _jc_jas_TableswitchOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_TableswitchOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
extern void _jc_jas_TableswitchOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_TableswitchOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_TableswitchOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_TableswitchOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_TableswitchOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_TableswitchOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_TableswitchOperand$vmethods	jas_TableswitchOperand;
};

// Vtype
struct _jc_jas_TableswitchOperand$vtype {
	_jc_type			type;
	_jc_jas_TableswitchOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_TableswitchOperand$sub_refs {
	struct _jc_jas_Label$object	*dflt;
	_jc_object_array	*jmp;
	struct _jc_jas_Insn$object	*source;
};

// Reference instance fields (object)
struct _jc_jas_TableswitchOperand$refs {
    _jc_jas_TableswitchOperand$sub_refs	jas_TableswitchOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_TableswitchOperand$sub_nonrefs {
	jint	min;
	jint	max;
};

// Non-reference instance fields (object)
struct _jc_jas_TableswitchOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_TableswitchOperand$sub_nonrefs	jas_TableswitchOperand;
};

// Object instance structure
struct _jc_jas_TableswitchOperand$object {
	_jc_jas_TableswitchOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_TableswitchOperand$vtype	*vtype;
	_jc_jas_TableswitchOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_TableswitchOperand$vtype _jc_jas_TableswitchOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_TableswitchOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_TableswitchOperand$class_object;

#endif	/* _JC_jas_TableswitchOperand_H_ */

==> jc-1.4.6.tar.gz: jas/TableswitchOperand.h <==
// class jas.TableswitchOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class f525ab7ff12da576 jas_TableswitchOperand
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_TableswitchOperand_H_
#define _JC_jas_TableswitchOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Insn$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_TableswitchOperand$sub_refs	_jc_jas_TableswitchOperand$sub_refs;
typedef struct _jc_jas_TableswitchOperand$sub_nonrefs	_jc_jas_TableswitchOperand$sub_nonrefs;
typedef struct _jc_jas_TableswitchOperand$refs	_jc_jas_TableswitchOperand$refs;
typedef struct _jc_jas_TableswitchOperand$nonrefs	_jc_jas_TableswitchOperand$nonrefs;
typedef struct _jc_jas_TableswitchOperand$object	_jc_jas_TableswitchOperand$object;

typedef const struct _jc_jas_TableswitchOperand$vmethods	_jc_jas_TableswitchOperand$vmethods;
typedef const struct _jc_jas_TableswitchOperand$vtable	_jc_jas_TableswitchOperand$vtable;
typedef const struct _jc_jas_TableswitchOperand$vtype	_jc_jas_TableswitchOperand$vtype;

// Constructors
extern void _jc_jas_TableswitchOperand$method$_init$cd7d55db5f4aa5ab(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_Insn$object *, jint, jint, struct _jc_jas_Label$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_TableswitchOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_TableswitchOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_TableswitchOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_TableswitchOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_TableswitchOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_TableswitchOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_TableswitchOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_TableswitchOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_TableswitchOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_TableswitchOperand$vmethods	jas_TableswitchOperand;
};

// Vtype
struct _jc_jas_TableswitchOperand$vtype {
	_jc_type			type;
	_jc_jas_TableswitchOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_TableswitchOperand$sub_refs {
	struct _jc_jas_Label$object	*dflt;
	_jc_object_array	*jmp;
	struct _jc_jas_Insn$object	*source;
};

// Reference instance fields (object)
struct _jc_jas_TableswitchOperand$refs {
    _jc_jas_TableswitchOperand$sub_refs	jas_TableswitchOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_TableswitchOperand$sub_nonrefs {
	jint	min;
	jint	max;
};

// Non-reference instance fields (object)
struct _jc_jas_TableswitchOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_TableswitchOperand$sub_nonrefs	jas_TableswitchOperand;
};

// Object instance structure
struct _jc_jas_TableswitchOperand$object {
	_jc_jas_TableswitchOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_TableswitchOperand$vtype	*vtype;
	_jc_jas_TableswitchOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_TableswitchOperand$vtype _jc_jas_TableswitchOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_TableswitchOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_TableswitchOperand$class_object;

#endif	/* _JC_jas_TableswitchOperand_H_ */
